pub struct Version(pub String);Tuple Fields
0: StringImplementations
Sourceimpl Version
impl Version
pub fn major(&self) -> Option<&str>
pub fn minor(&self) -> Option<&str>
Sourcepub fn is_v1_1(&self) -> bool
pub fn is_v1_1(&self) -> bool
Returns true if the ABI version is 1.1.
The v1.1 introduced the “errorCodes” field:
- each “errorCodes” entry key is equal to a revert code generated by a
panicexpression.
Sourcepub fn is_v1_2(&self) -> bool
pub fn is_v1_2(&self) -> bool
Returns true if the ABI version is 1.2.
The v1.2 introduced the “panickingCalls” field and changed the semantics of the key in the “errorCodes” field:
- the key in the “errorCodes” field is the
u64value of thepppppppppart of the1_pppppppp_CCCCCCCCCCC_CCCCCCCCCCC_CCCCCCCCCCC_CCCCCCCCCCC_CCCCCCCCCCCencoded revert code generated by apanicexpression.